"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class CheckoutCustomerBillingAddressFieldsTypedDict(TypedDict):
    country: bool
    state: bool
    city: bool
    postal_code: bool
    line1: bool
    line2: bool


class CheckoutCustomerBillingAddressFields(BaseModel):
    country: bool

    state: bool

    city: bool

    postal_code: bool

    line1: bool

    line2: bool



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel
from typing_extensions import TypedDict


class MeterResetMetadataTypedDict(TypedDict):
    meter_id: str


class MeterResetMetadata(BaseModel):
    meter_id: str
